@@ -13,11 +13,9 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Watcher';
 
-use Zing::Channel;
 use Zing::Logic::Kernel;
-use Zing::Term;
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 # ATTRIBUTES
 
@@ -28,7 +26,7 @@ has 'journal' => (
 );
 
 fun new_journal($self) {
-  Zing::Channel->new(name => '$journal')
+  $self->app->journal
 }
 
 has 'scheme' => (
@@ -40,13 +38,14 @@ has 'scheme' => (
 # BUILDERS
 
 fun new_logic($self) {
-  Zing::Logic::Kernel->new(process => $self);
+  my $debug = $self->env->debug;
+  Zing::Logic::Kernel->new(debug => $debug, process => $self)
 }
 
 # METHODS
 
 method term() {
-  return Zing::Term->new($self)->kernel;
+  return $self->app->term($self)->kernel;
 }
 
 1;
