@@ -10,52 +10,45 @@ use routines;
 
 use Data::Object::Class;
 use Data::Object::ClassHas;
+use Data::Object::Space;
 
-use Zing::Node;
-use Zing::Server;
+extends 'Zing::Class';
 
-use Carp ();
 use Scalar::Util ();
 
 use overload '""' => 'string';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 # ATTRIBUTES
 
-has 'facets' => (
-  is => 'ro',
-  isa => 'ArrayRef[Str]',
-  opt => 1,
-);
-
 has 'handle' => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'Name',
   req => 1,
 );
 
 has 'symbol' => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'Name',
   req => 1,
 );
 
 has 'bucket' => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'Name',
   req => 1,
 );
 
 has 'system' => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'Name',
   req => 1,
 );
 
 has 'target' => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'Name',
   req => 1,
 );
 
@@ -67,11 +60,12 @@ state $symbols = {
   'Zing::Domain'   => 'domain',
   'Zing::Kernel'   => 'kernel',
   'Zing::KeyVal'   => 'keyval',
+  'Zing::Lookup'   => 'lookup',
   'Zing::Mailbox'  => 'mailbox',
+  'Zing::Meta'     => 'meta',
   'Zing::Process'  => 'process',
   'Zing::PubSub'   => 'pubsub',
   'Zing::Queue'    => 'queue',
-  'Zing::Registry' => 'registry',
   'Zing::Repo'     => 'repo',
 };
 
@@ -79,106 +73,75 @@ fun BUILDARGS($self, $item, @data) {
   my $args = {};
 
   if (Scalar::Util::blessed($item)) {
-    my $local = sprintf 'local(%s)', Zing::Server->new->name;
-
-    @data = map {split /:/} @data;
-
     if ($item->isa('Zing::Data')) {
-      my ($bucket, @facets) = split /:/, $item->name;
       $args->{symbol} = $symbols->{'Zing::Data'};
-      $args->{target} = $local;
-      $args->{bucket} = $bucket;
-      $args->{facets} = [@facets, @data];
+      $args->{bucket} = $item->name;
+    }
+    elsif ($item->isa('Zing::Lookup')) {
+      $args->{symbol} = $symbols->{'Zing::Lookup'};
+      $args->{bucket} = $item->name;
     }
     elsif ($item->isa('Zing::Domain')) {
       $args->{symbol} = $symbols->{'Zing::Domain'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     elsif ($item->isa('Zing::Channel')) {
       $args->{symbol} = $symbols->{'Zing::Channel'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     elsif ($item->isa('Zing::Kernel')) {
-      my ($bucket, @facets) = split /:/, $item->name;
       $args->{symbol} = $symbols->{'Zing::Kernel'};
-      $args->{target} = $local;
-      $args->{bucket} = $bucket;
-      $args->{facets} = [@facets, @data];
+      $args->{bucket} = $item->name;
     }
     elsif ($item->isa('Zing::Mailbox')) {
-      my ($bucket, @facets) = split /:/, $item->name;
       $args->{symbol} = $symbols->{'Zing::Mailbox'};
-      $args->{target} = 'global';
-      $args->{bucket} = $bucket;
-      $args->{facets} = [@facets, @data];
+      $args->{bucket} = $item->name;
     }
     elsif ($item->isa('Zing::Process')) {
-      my ($bucket, @facets) = split /:/, $item->name;
       $args->{symbol} = $symbols->{'Zing::Process'};
-      $args->{target} = $local;
-      $args->{bucket} = $bucket;
-      $args->{facets} = [@facets, @data];
+      $args->{bucket} = $item->name;
     }
     elsif ($item->isa('Zing::Queue')) {
       $args->{symbol} = $symbols->{'Zing::Queue'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
-    elsif ($item->isa('Zing::Registry')) {
-      $args->{symbol} = $symbols->{'Zing::Registry'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
+    elsif ($item->isa('Zing::Meta')) {
+      $args->{symbol} = $symbols->{'Zing::Meta'};
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     elsif ($item->isa('Zing::KeyVal')) {
       $args->{symbol} = $symbols->{'Zing::KeyVal'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     elsif ($item->isa('Zing::PubSub')) {
       $args->{symbol} = $symbols->{'Zing::PubSub'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     elsif ($item->isa('Zing::Repo')) {
       $args->{symbol} = $symbols->{'Zing::Repo'};
-      $args->{target} = $item->target eq 'global' ? 'global' : $local;
       $args->{bucket} = $item->name;
-      $args->{facets} = [@data];
     }
     else {
-      Carp::confess qq(Error in term: Unrecognizable "object");
+      $self->throw(error_term_unknow_object($item));
     }
-    $args->{handle} = ($ENV{ZING_HANDLE} || $ENV{ZING_NS} || 'main') =~ s/\W/-/gr;
+    $args->{target} = ($item->env->target || 'global');
+    $args->{handle} = ($item->env->handle || 'main');
     $args->{system} = 'zing';
   }
   elsif(defined $item && !ref $item) {
-    my $schema = [split /:/, "$item", 6];
+    my $schema = [split /:/, "$item", 5];
 
     my $system = $schema->[0];
     my $handle = $schema->[1];
     my $target = $schema->[2];
     my $symbol = $schema->[3];
     my $bucket = $schema->[4];
-    my $extras = $schema->[5];
-
-    my $facets = [split /:/, $extras || ''];
 
     unless ($system eq 'zing') {
-      Carp::confess qq(Error in term: Unrecognizable "system" in: $item);
-    }
-    unless ($target =~ m{^(global|local\(\d+\.\d+\.\d+\.\d+\))$}) {
-      Carp::confess qq(Error in term: Unrecognizable "target" ($target) in: $item);
+      $self->throw(error_term_unknow_system("$item"));
     }
     unless (grep {$_ eq $symbol} values %$symbols) {
-      Carp::confess qq(Error in term: Unrecognizable "symbol" ($symbol) in: $item);
+      $self->throw(error_term_unknow_symbol("$item"));
     }
 
     $args->{system} = $system;
@@ -186,10 +149,9 @@ fun BUILDARGS($self, $item, @data) {
     $args->{target} = $target;
     $args->{symbol} = $symbol;
     $args->{bucket} = $bucket;
-    $args->{facets} = $facets;
   }
   else {
-    Carp::confess 'Unrecognizable Zing term provided';
+    $self->throw(error_term_unknown());
   }
 
   return $args;
@@ -199,7 +161,7 @@ fun BUILDARGS($self, $item, @data) {
 
 method channel() {
   unless ($self->symbol eq 'channel') {
-    Carp::confess 'Error in term: not a "channel"';
+    $self->throw(error_term_invalid("channel"));
   }
 
   return $self->string;
@@ -207,7 +169,7 @@ method channel() {
 
 method data() {
   unless ($self->symbol eq 'data') {
-    Carp::confess 'Error in term: not a "data" term';
+    $self->throw(error_term_invalid("data"));
   }
 
   return $self->string;
@@ -215,7 +177,7 @@ method data() {
 
 method domain() {
   unless ($self->symbol eq 'domain') {
-    Carp::confess 'Error in term: not a "domain" term';
+    $self->throw(error_term_invalid("domain"));
   }
 
   return $self->string;
@@ -223,7 +185,7 @@ method domain() {
 
 method kernel() {
   unless ($self->symbol eq 'kernel') {
-    Carp::confess 'Error in term: not a "kernel" term';
+    $self->throw(error_term_invalid("kernel"));
   }
 
   return $self->string;
@@ -231,7 +193,15 @@ method kernel() {
 
 method keyval() {
   unless ($self->symbol eq 'keyval') {
-    Carp::confess 'Error in term: not a "keyval" term';
+    $self->throw(error_term_invalid("keyval"));
+  }
+
+  return $self->string;
+}
+
+method lookup() {
+  unless ($self->symbol eq 'lookup') {
+    $self->throw(error_term_invalid("lookup"));
   }
 
   return $self->string;
@@ -239,15 +209,38 @@ method keyval() {
 
 method mailbox() {
   unless ($self->symbol eq 'mailbox') {
-    Carp::confess 'Error in term: not a "mailbox" term';
+    $self->throw(error_term_invalid("mailbox"));
   }
 
   return $self->string;
 }
 
+method meta() {
+  unless ($self->symbol eq 'meta') {
+    $self->throw(error_term_invalid("meta"));
+  }
+
+  return $self->string;
+}
+
+method object() {
+  require Zing::Env;
+
+  my $env = Zing::Env->new(
+    handle => $self->handle,
+    target => $self->target,
+  );
+
+  my $space = Data::Object::Space->new(
+    ({reverse %$symbols})->{$self->symbol}
+  );
+
+  return $space->build(env => $env, name => $self->bucket);
+}
+
 method process() {
   unless ($self->symbol eq 'process') {
-    Carp::confess 'Error in term: not a "process" term';
+    $self->throw(error_term_invalid("process"));
   }
 
   return $self->string;
@@ -255,7 +248,7 @@ method process() {
 
 method pubsub() {
   unless ($self->symbol eq 'pubsub') {
-    Carp::confess 'Error in term: not a "pubsub" term';
+    $self->throw(error_term_invalid("pubsub"));
   }
 
   return $self->string;
@@ -263,15 +256,7 @@ method pubsub() {
 
 method queue() {
   unless ($self->symbol eq 'queue') {
-    Carp::confess 'Error in term: not a "queue" term';
-  }
-
-  return $self->string;
-}
-
-method registry() {
-  unless ($self->symbol eq 'registry') {
-    Carp::confess 'Error in term: not a "registry" term';
+    $self->throw(error_term_invalid("queue"));
   }
 
   return $self->string;
@@ -279,7 +264,7 @@ method registry() {
 
 method repo() {
   unless ($self->symbol eq 'repo') {
-    Carp::confess 'Error in term: not a "repo" term';
+    $self->throw(error_term_invalid('repo'));
   }
 
   return $self->string;
@@ -291,9 +276,35 @@ method string() {
   my $target = $self->target;
   my $symbol = $self->symbol;
   my $bucket = $self->bucket;
-  my $facets = $self->facets || [];
 
-  return lc join ':', $system, $handle, $target, $symbol, $bucket, @$facets;
+  return lc join ':', $system, $handle, $target, $symbol, $bucket;
+}
+
+# ERRORS
+
+fun error_term_invalid(Str $name) {
+  code => 'error_term_invalid',
+  message => qq(Error in term: not a "$name" term),
+}
+
+fun error_term_unknown() {
+  code => 'error_term_unknown',
+  message => qq(Unrecognizable term (or object) provided),
+}
+
+fun error_term_unknow_object(Object $item) {
+  code => 'error_term_unknow_object',
+  message => qq(Error in term: Unrecognizable "object": $item),
+}
+
+fun error_term_unknow_symbol(Str $term) {
+  code => 'error_term_unknow_symbol',
+  message => qq(Error in term: Unrecognizable "symbol" in: $term),
+}
+
+fun error_term_unknow_system(Str $term) {
+  code => 'error_term_unknow_system',
+  message => qq(Error in term: Unrecognizable "system" in: $term),
 }
 
 1;
@@ -352,14 +363,6 @@ This attribute is read-only, accepts C<(Str)> values, and is required.
 
 =cut
 
-=head2 facets
-
-  facets(ArrayRef[Str])
-
-This attribute is read-only, accepts C<(ArrayRef[Str])> values, and is optional.
-
-=cut
-
 =head2 handle
 
   handle(Str)
@@ -431,7 +434,7 @@ The data method validates and returns a "data" resource identifier.
   use Zing::Data;
   use Zing::Process;
 
-  Zing::Term->new(Zing::Data->new(process => Zing::Process->new));
+  Zing::Term->new(Zing::Data->new(name => '0.0.0.0'));
 
   # $term->data;
 
@@ -499,6 +502,26 @@ The keyval method validates and returns a "keyval" resource identifier.
 
 =cut
 
+=head2 lookup
+
+  lookup() : Str
+
+The lookup method validates and returns a "lookup" resource identifier.
+
+=over 4
+
+=item lookup example #1
+
+  use Zing::Lookup;
+
+  Zing::Term->new(Zing::Lookup->new(name => 'employees'));
+
+  # $term->lookup;
+
+=back
+
+=cut
+
 =head2 mailbox
 
   mailbox() : Str
@@ -512,7 +535,7 @@ The mailbox method validates and returns a "mailbox" resource identifier.
   use Zing::Mailbox;
   use Zing::Process;
 
-  Zing::Term->new(Zing::Mailbox->new(process => Zing::Process->new));
+  Zing::Term->new(Zing::Mailbox->new(name => '0.0.0.0'));
 
   # $term->mailbox;
 
@@ -520,6 +543,46 @@ The mailbox method validates and returns a "mailbox" resource identifier.
 
 =cut
 
+=head2 meta
+
+  meta() : Str
+
+The meta method validates and returns a "meta" resource identifier.
+
+=over 4
+
+=item meta example #1
+
+  use Zing::Meta;
+
+  Zing::Term->new(Zing::Meta->new(name => 'random'));
+
+  # $term->meta;
+
+=back
+
+=cut
+
+=head2 object
+
+  object() : Object
+
+The object method reifies an object from its resource identifier.
+
+=over 4
+
+=item object example #1
+
+  use Zing::Process;
+
+  my $term = Zing::Term->new(Zing::Process->new);
+
+  $term->object;
+
+=back
+
+=cut
+
 =head2 process
 
   process() : Str
@@ -580,26 +643,6 @@ The queue method validates and returns a "queue" resource identifier.
 
 =cut
 
-=head2 registry
-
-  registry() : Str
-
-The registry method validates and returns a "registry" resource identifier.
-
-=over 4
-
-=item registry example #1
-
-  use Zing::Registry;
-
-  Zing::Term->new(Zing::Registry->new(name => 'campaigns'));
-
-  # $term->registry;
-
-=back
-
-=cut
-
 =head2 repo
 
   repo() : Str
